@@ -24,7 +24,7 @@
 
 
 __project__ = "pigit"
-__version__ = "1.3.2"
+__version__ = "1.3.3"
 __url__ = "https://github.com/zlj-zz/pigit.git"
 __uri__ = __url__
 
@@ -42,8 +42,8 @@ import logging
 from shutil import get_terminal_size
 from typing import Optional, Union
 
-from .log import LogHandle
-from .common import Color, Fx, TermColor, color_print
+from .log import setup_logging
+from .common import Color, render_str, get_current_shell
 from .gitinfo import (
     Git_Version,
     REPOSITORY_PATH,
@@ -53,8 +53,8 @@ from .gitinfo import (
 from .decorator import time_it
 from .config import Config
 from .codecounter import CodeCounter
-from .shell_completion import ShellCompletion, process_argparse
 from .gitignore import GitignoreGenetor
+from .shellcompletion import shell_compele, process_argparse
 from .interaction import InteractiveStatus, InteractiveCommit
 from .processor import CmdProcessor, Git_Cmds, CommandType
 
@@ -115,36 +115,34 @@ def introduce() -> None:
 
     # Print git version.
     if Git_Version is None:
-        color_print("Don't found Git, maybe need install.", TermColor.Red)
+        print(render_str("`Don't found Git, maybe need install.`<error>"))
     else:
         print(Git_Version)
 
     # Print package path.
-    color_print("Local path: ", Fx.b, end="")
-    f_p = __file__.replace("./", "")  # f_p -> file path
-    color_print("%s\n" % f_p, TermColor.SkyBlue, Fx.underline)
+    print(
+        render_str(
+            "b`Local path`: u`{}`<sky_blue>\n".format(__file__.replace("./", ""))
+        )
+    )
 
     # Print description.
-    color_print("Description:", Fx.b)
-    color_print(
-        "  Terminal tool, help you use git more simple."
-        " Support Linux, MacOS and Windows.\n"
-        "  It use short command to replace the original command, like: \n"
-        "  ``{green}pigit ws{rs}`` -> ``{green}git status --short{rs}``,"
-        " ``{green}pigit b{rs}`` -> ``{green}git branch{rs}``.\n"
-        "  Also you use ``{green}pigit -s{rs}`` to get the all short command,"
-        " have fun and good lucky.\n"
-        "  The open source path on github: {url}".format(
-            url=TermColor.SkyBlue + Fx.underline + __url__,
-            green=TermColor.Green,
-            rs=Fx.reset,
-        ),
-        Fx.italic,
+    print(
+        render_str(
+            "b`Description:`\n"
+            "  Terminal tool, help you use git more simple."
+            " Support Linux, MacOS and Windows.\n"
+            "  It use short command to replace the original command, like: \n"
+            "  ``pigit ws``<ok> -> ``git status --short``<ok>,"
+            " ``pigit b``<ok> -> ``git branch``<ok>.\n"
+            "  Also you use ``pigit -s``<ok> to get the all short command,"
+            " have fun and good lucky.\n"
+            f"  The open source path on github: u`{__url__}`<sky_blue>"
+        )
     )
 
     print(
-        "\nYou can use {green}-h{rs} or {green}--help{rs} "
-        "to get help and more usage.".format(green=TermColor.Green, rs=Fx.reset)
+        render_str("\nYou can use `-h`<ok> or `--help`<ok> to get help and more usage.")
     )
 
 
@@ -188,38 +186,91 @@ def shell_mode(git_processor: CmdProcessor):
         "Welcome come PIGIT shell.\n"
         "You can use short commands directly. Input '?' to get help.\n"
     )
-    while True:
-        command = input("(pigit)> ").strip()
-        if not command:
+
+    stopping: bool = False
+
+    while not stopping:
+        if not (input_argv_str := input("(pigit)> ").strip()):
             continue
 
-        command_args = command.split()
-        head_command = command_args[0]
+        # Explode command string.
+        argv = input_argv_str.split(maxsplit=1)
+        command = argv[0]
+        args_str = argv[1] if len(argv) == 2 else ""
 
-        if head_command in ["quit", "exit"]:  # ctrl+c
-            break
-        elif head_command in git_processor.cmds.keys():
-            git_processor.process_command(head_command, command_args[1:])
-        elif head_command == "tomato":
+        # Process.
+        if command in ["quit", "exit"]:  # ctrl+c
+            stopping = True
+
+        elif command in git_processor.cmds.keys():
+            git_processor.process_command(command, args_str.split())
+
+        elif command == "tomato":
             # Tomato clock.
-            pigit.tomato.main(command_args)
-        elif head_command == "?":
-            other_ = command_args[1:]
-            if not other_:
-                git_processor.command_help()
+            pigit.tomato.main(input_argv_str.split())
+
+        elif command in ["sh", "shell"]:
+            if args_str:
+                os.system(args_str)
             else:
-                print(other_)
-                for item in other_:
+                print("pigit shell: Please input shell command.")
+
+        elif command == "?":
+            if not args_str:
+                print(
+                    "Options:\n"
+                    "  quit, exit      Exit the pigit shell mode.\n"
+                    "  sh, shell       Run a shell command.\n"
+                    "  tomato          It's a terminal tomato clock.\n"
+                    "  ? [comand...]   Show help message. Use `? ?` to look detail.\n"
+                )
+
+            elif "?" in args_str:
+                print(
+                    "? is a tip command."
+                    "Use `?` to look pigit shell options."
+                    "Use `? [command...]` to look option help message.\n"
+                    "Like:\n"
+                    "`? sh` to get the help of sh command.\n"
+                    "`? all` to get all support git quick command help.\n"
+                    "Or `? ws ls` to get the help you want.\n"
+                )
+
+            elif "all" in args_str:
+                git_processor.command_help()
+
+            elif "tomato" in args_str:
+                pigit.tomato.help("tomato")
+
+            elif "sh" in args_str or "shell" in args_str:
+                print(
+                    "This command is help you to run a normal terminal command in pigit shell.\n"
+                    "For example, you can use `sh ls` to check the files of current dir.\n"
+                )
+
+            else:
+                invalid = []
+
+                for item in args_str.split():
                     if item in git_processor.cmds.keys():
                         print(git_processor._generate_help_by_key(item))
-                    elif item == "tomato":
-                        pigit.tomato.help("tomato")
+                    else:
+                        invalid.append(item)
+
+                if invalid:
+                    print("Cannot find command: {0}".format(",".join(invalid)))
+
         else:
-            os.system(command)
+            print(
+                "pigit shell: Invalid command `{0}`, please select from "
+                "[shell, tomato, quit] or git short command.".format(command)
+            )
+
     return None
 
 
 def interactive_interface(args):
+    cache_flag: int = 1  # prevent range out, caches the last selection.
     flag: int = 1
 
     if args:
@@ -229,17 +280,19 @@ def interactive_interface(args):
 
     while flag and flag > 0:
         if flag == 1:
+            cache_flag = flag
             flag = InteractiveStatus(
                 use_color=CONFIG.gitprocessor_interactive_color,
                 help_wait=CONFIG.gitprocessor_interactive_help_showtime,
             ).run()
         elif flag == 2:
+            cache_flag = flag
             flag = InteractiveCommit(
                 use_color=CONFIG.gitprocessor_interactive_color,
                 help_wait=CONFIG.gitprocessor_interactive_help_showtime,
             ).run()
         else:
-            flag = 1
+            flag = cache_flag
 
 
 class CustomHelpFormatter(argparse.HelpFormatter):
@@ -301,7 +354,7 @@ class CustomHelpFormatter(argparse.HelpFormatter):
             _color = self.colors["green"]
         else:
             _color = ""
-        parts = [_color + action_header + Fx.reset]
+        parts = [_color + action_header + "\033[0m"]
 
         # if there was help for the action, add lines of help text
         if action.help:
@@ -365,7 +418,7 @@ class Parser(object):
             "-C",
             "--complete",
             action="store_true",
-            help="Add shell prompt script and exit.(Supported `bash`, `zsh`, `fish`)",
+            help="Add shell prompt script and exit.(Supported bash, zsh, fish)",
         )
         p.add_argument(
             "-s",
@@ -431,13 +484,13 @@ class Parser(object):
             type=str,
             metavar="TYPE",
             dest="ignore_type",
-            help="Create a demo `.gitignore` file. Need one argument, support: [%s]"
+            help="Create a demo .gitignore file. Need one argument, support: [%s]"
             % ", ".join(GitignoreGenetor.Supported_Types.keys()),
         )
         p.add_argument(
             "--create-config",
             action="store_true",
-            help="Create a preconfigured file of PIGIT."
+            help="Create a pre-configured file of PIGIT."
             "(If a profile exists, the values available in it are used)",
         )
         tool_group.add_argument(
@@ -469,17 +522,15 @@ class Parser(object):
 
     def process(self, known_args, extra_unknown: Optional[list] = None) -> None:
         try:
-            if known_args.config:
-                output_git_local_config(CONFIG.git_config_format)
+            known_args.config and output_git_local_config(CONFIG.git_config_format)
 
-            if known_args.information:
-                output_repository_info(
-                    show_path=CONFIG.repository_show_path,
-                    show_remote=CONFIG.repository_show_remote,
-                    show_branches=CONFIG.repository_show_branchs,
-                    show_lastest_log=CONFIG.repository_show_lastest_log,
-                    show_summary=CONFIG.repository_show_summary,
-                )
+            known_args.information and output_repository_info(
+                show_path=CONFIG.repository_show_path,
+                show_remote=CONFIG.repository_show_remote,
+                show_branches=CONFIG.repository_show_branchs,
+                show_lastest_log=CONFIG.repository_show_lastest_log,
+                show_summary=CONFIG.repository_show_summary,
+            )
 
             if known_args.complete:
                 # Generate competion vars dict.
@@ -490,20 +541,21 @@ class Parser(object):
                 # Update var dict with shell command.
                 completion_vars.update(process_argparse(self._parser))
 
-                ShellCompletion(
-                    __project__, completion_vars, PIGIT_HOME
-                ).complete_and_use()
+                shell_compele(
+                    get_current_shell(), __project__, completion_vars, PIGIT_HOME
+                )
                 return None
 
             if known_args.create_config:
                 return CONFIG.create_config_template()
 
             if known_args.ignore_type:
-                GitignoreGenetor(timeout=CONFIG.gitignore_generator_timeout,).launch(
+                return GitignoreGenetor(
+                    timeout=CONFIG.gitignore_generator_timeout,
+                ).launch(
                     known_args.ignore_type,
                     dir_path=REPOSITORY_PATH,
                 )
-                return None
 
             if known_args.count:
                 path = known_args.count if known_args.count != "." else os.getcwd()
@@ -527,7 +579,8 @@ class Parser(object):
                     "has_arguments": True,
                 },
                 "shell": {
-                    "command": "",
+                    "command": lambda _: shell_mode(git_processor),
+                    "type": "func",
                     "help": "Into PIGIT shell mode.",
                 },  # only for tips.
             }
@@ -554,13 +607,10 @@ class Parser(object):
                 return git_processor.type_help()
 
             if known_args.command:
-                if known_args.command == "shell":
-                    return shell_mode(git_processor)
-                else:
-                    command = known_args.command
-                    known_args.args.extend(extra_unknown)  # type: list
-                    git_processor.process_command(command, known_args.args)
-                    return None
+                command = known_args.command
+                known_args.args.extend(extra_unknown)
+                git_processor.process_command(command, known_args.args)
+                return None
 
             # Don't have invalid command list.
             if not list(filter(lambda x: x, vars(known_args).values())):
@@ -580,7 +630,7 @@ def main(custom_commands: Optional[list] = None):
 
     # Setup log handle.
     log_file = LOG_PATH if stdargs.out_log or CONFIG.stream_output_log else None
-    LogHandle.setup_logging(debug=stdargs.debug or CONFIG.debug_mode, log_file=log_file)
+    setup_logging(debug=stdargs.debug or CONFIG.debug_mode, log_file=log_file)
 
     # Process result.
     parser.process(stdargs, extra_unknown)
