@@ -1,32 +1,82 @@
 # -*- coding:utf-8 -*-
 
-"""This file support some str util method."""
+"""This file support some str util method.
+
+Docs Test
+
+    The width occupied by a given character when displayed.
+
+        >>> get_width(ord('a'))
+        1
+        >>> get_width(ord('中'))
+        2
+        >>> get_width(ord('Ç'))
+        1
+
+    Determine the type of file by file name.
+
+        >>> adjudgment_type('test.py')
+        'Python'
+        >>> adjudgment_type('xxxxx')
+        'unknown'
+        >>> adjudgment_type('xxxxx', True)
+        'xxxxx'
+
+    Intercepts a string by a given length.
+
+        >>> shorten('Hello world!', 9, placeholder='^-^')
+        'Hello ^-^'
+        >>> shorten('Hello world!', 9, placeholder='^-^', front=True)
+        '^-^world!'
+"""
 
 # from typing import Final # python3.8
 
-# yapf: disable
-WIDTHS: list[tuple[int,int]] = [
-    (126, 1), (159, 0), (687, 1), (710, 0), (711, 1), (727, 0), (733, 1), (879, 0),
-    (1154, 1), (1161, 0), (4347, 1), (4447, 2), (7467, 1),
-    (7521, 0), (8369, 1), (8426, 0), (9000, 1), (9002, 2),
-    (11021, 1), (12350, 2), (12351, 1), (12438, 2), (12442, 0), (19893, 2),
-    (19967, 1), (55203, 2), (63743, 1), (64106, 2), (65039, 1), (65059, 0),
-    (65131, 2), (65279, 1), (65376, 2), (65500, 1), (65510, 2), (120831, 1),
-    (262141, 2), (1114109, 1),
+WIDTHS: list[tuple[int, int]] = [
+    (126, 1),
+    (159, 0),
+    (687, 1),
+    (710, 0),
+    (711, 1),
+    (727, 0),
+    (733, 1),
+    (879, 0),
+    (1154, 1),
+    (1161, 0),
+    (4347, 1),
+    (4447, 2),
+    (7467, 1),
+    (7521, 0),
+    (8369, 1),
+    (8426, 0),
+    (9000, 1),
+    (9002, 2),
+    (11021, 1),
+    (12350, 2),
+    (12351, 1),
+    (12438, 2),
+    (12442, 0),
+    (19893, 2),
+    (19967, 1),
+    (55203, 2),
+    (63743, 1),
+    (64106, 2),
+    (65039, 1),
+    (65059, 0),
+    (65131, 2),
+    (65279, 1),
+    (65376, 2),
+    (65500, 1),
+    (65510, 2),
+    (120831, 1),
+    (262141, 2),
+    (1114109, 1),
 ]
-# yapf: enable
 
 
 def get_width(r: int) -> int:
-    """Gets the width occupied by characters on the command line.
+    """Gets the width occupied by characters on the command line."""
 
-    >>> get_width(ord('a'))
-    1
-    >>> get_width(ord('中'))
-    2
-    >>> get_width(ord('Ç'))
-    1
-    """
     if r == 0xE or r == 0xF:
         return 0
     for num, wid in WIDTHS:
@@ -78,18 +128,15 @@ SUFFIX_TYPE: dict[str, str] = {
     "rc": "Properties",
     "rs": "Rust",
     "rst": "reStructuredText",
-    "rviz": "YAML",
     "ts": "Type Script",
     "tsx": "React",
     "sass": "CSS",
     "scss": "CSS",
     "sh": "Shell",
     "sql": "SQL",
-    "srdf": "YAML",
     "srv": "ROS Message",
     "swift": "Swift",
     "toml": "Properties",
-    "urdf": "XML",
     "vb": "Visual Basic",
     "vim": "Vim Scirpt",
     "vue": "Vue",
@@ -121,13 +168,6 @@ def adjudgment_type(file: str, original: bool = False) -> str:
 
     Returns:
         (str): file type.
-
-    >>> adjudgment_type('test.py')
-    'Python'
-    >>> adjudgment_type('xxxxx')
-    'unknown'
-    >>> adjudgment_type('xxxxx', True)
-    'xxxxx'
     """
 
     pre_type = SPECIAL_NAMES.get(file.lower(), None)
@@ -187,13 +227,6 @@ def get_file_icon(file_type: str) -> str:
 
     Returns:
         str: icon.
-
-    >>> get_file_icon('Python')
-    ''
-    >>> get_file_icon('Lua')
-    ''
-    >>> get_file_icon('xxxxxxxxxx')
-    ''
     """
 
     #     
@@ -213,11 +246,6 @@ def shorten(
 
     Returns:
         (str): shorten string.
-
-    >>> shorten('Hello world!', 9, placeholder='^-^')
-    'Hello ^-^'
-    >>> shorten('Hello world!', 9, placeholder='^-^', front=True)
-    '^-^world!'
     """
 
     if len(text) > width:
