@@ -7,7 +7,7 @@ from abc import ABC, abstractmethod
 from shutil import get_terminal_size
 from typing import Optional, Any
 
-from ..common import Fx, TermColor, exec_cmd, shorten, get_width, color_print
+from ..common import Term, Fx, exec_cmd, shorten, get_width, render_str
 from ..common.singleton import Singleton
 from ..keyevent import get_keyevent_obj
 from ..gitinfo import REPOSITORY_PATH
@@ -63,24 +63,9 @@ class DataHandle(object, metaclass=Singleton):
 
             display_name = shorten(name, max_width - 3 - ident)
             # color full command.
-            if unstaged_change != " ":
-                if not has_no_staged_change:
-                    display_str = "{}{}{}{} {}{}".format(
-                        TermColor.Green,
-                        staged_change,
-                        TermColor.Red,
-                        unstaged_change,
-                        display_name,
-                        Fx.reset,
-                    )
-                else:
-                    display_str = "{}{} {}{}".format(
-                        TermColor.Red, change, display_name, Fx.reset
-                    )
-            else:
-                display_str = "{}{} {}{}".format(
-                    TermColor.Green, change, display_name, Fx.reset
-                )
+            display_str = render_str(
+                f"`{staged_change}`<{'bad' if has_no_staged_change else'right'}>`{unstaged_change}`<{'bad' if unstaged_change!=' ' else'right'}> {display_name}"
+            )
 
             file_ = File(
                 name=name,
@@ -115,20 +100,11 @@ class DataHandle(object, metaclass=Singleton):
 
         command = "git diff --submodule --no-ext-diff {plain} {cached} {tracked} {file}"
 
-        if plain:
-            _plain = "--color=never"
-        else:
-            _plain = "--color=always"
+        _plain = "--color=never" if plain else "--color=always"
 
-        if cached:
-            _cached = "--cached"
-        else:
-            _cached = ""
+        _cached = "--cached" if cached else ""
 
-        if not tracked:
-            _tracked = "--no-index -- /dev/null"
-        else:
-            _tracked = "--"
+        _tracked = "--no-index -- /dev/null" if not tracked else "--"
 
         if "->" in file:  # rename status.
             file = file.split("->")[-1].strip()
@@ -167,42 +143,40 @@ class DataHandle(object, metaclass=Singleton):
         command = f'git log {branch_name} --oneline --pretty=format:"%H|%at|%aN|%d|%p|%s" {limit_flag} --abbrev=20 --date=unix {filter_flag}'
         err, resp = exec_cmd(command)
 
+        if err:
+            return commits  # current is empty list.
+
         # Process data.
-        lines = resp.split("\n")
-        if not err:
-            for line in lines:
-                split_ = line.split("|")
+        for line in resp.split("\n"):
+            split_ = line.split("|")
 
-                sha = split_[0]
-                unix_timestamp = int(split_[1])
-                author = split_[2]
-                extra_info = (split_[3]).strip()
-                # parent_hashes = split_[4]
-                message = "|".join(split_[5:])
+            sha = split_[0]
+            unix_timestamp = int(split_[1])
+            author = split_[2]
+            extra_info = (split_[3]).strip()
+            # parent_hashes = split_[4]
+            message = "|".join(split_[5:])
 
-                tag = []
-                if extra_info:
-                    _re = re.compile(r"tag: ([^,\\]+)")
-                    match = _re.search(extra_info)
-                    if match:
-                        tag.append(match[1])
+            tag = []
+            if extra_info:
+                _re = re.compile(r"tag: ([^,\\]+)")
+                if match := _re.search(extra_info):
+                    tag.append(match[1])
 
-                if sha == first_pushed_commit:
-                    passed_first_pushed_commit = True
-                status = {True: "unpushed", False: "pushed"}[
-                    not passed_first_pushed_commit
-                ]
+            if sha == first_pushed_commit:
+                passed_first_pushed_commit = True
+            status = {True: "unpushed", False: "pushed"}[not passed_first_pushed_commit]
 
-                commit_ = Commit(
-                    sha=sha,
-                    msg=message,
-                    author=author,
-                    unix_timestamp=unix_timestamp,
-                    status=status,
-                    extra_info=extra_info,
-                    tag=tag,
-                )
-                commits.append(commit_)
+            commit_ = Commit(
+                sha=sha,
+                msg=message,
+                author=author,
+                unix_timestamp=unix_timestamp,
+                status=status,
+                extra_info=extra_info,
+                tag=tag,
+            )
+            commits.append(commit_)
 
         return commits
 
@@ -225,9 +199,60 @@ class DataHandle(object, metaclass=Singleton):
 
 
 # whether already in interactive mode.
-_Interaction_Starting = False
-
+_Interaction_Starting: bool = False
 
+# ``_Interaction`` is the basic class of an interactive page. When a subclass wants to
+# implement a page, it inherits it and needs to implement the reserved interface.
+#
+# Interface:
+#   process_keyevent()
+#   keyevent_help()
+#   get_raw_data()
+#   print_line()
+#
+# Can overwrite:
+#   process_raw_data()
+#
+# `run` structure:
+# =========================================================================================
+#         Main flow                           Loop flow
+# +--------------------------+
+# | checking                 |
+# +--------------------------|
+# | whether git repo         |
+# | whether has enough space |
+# +--------------------------+
+#              |
+#              |                        +----------------------+
+#     +----------------+                | get data             |
+#     | init hook      |             +->+----------------------+
+#     |                |             |  | `get_raw_data()`     |<----------------------+
+#     +----------------+             |  | `process_raw_data()` |                       |
+#              |                     |  +----------------------+                       |
+#              |                     |             |                                   |
+#              |                     |             |                                   |
+#     +----------------+             |   +------------------+                          |
+#     |                |             |   | refresh display  |<--------+                |
+#     |                |--first into-+   +------------------+         |                |
+#     |    loop        |                           |                  |                |
+#     |                |                           |                  |                |
+#     |                |<--------+      +---------------------+       |                |
+#     +----------------+         |      |                     |       |                |
+#              |                 |      | wait keyboard input |       |                |
+#              |                 |      |                     |       |                |
+#              |                 |      +---------------------+       |                |
+#              |                 |                 |                  |      +----------------------+
+#     +----------------+         |                 |                  |      | process custom event |
+#     | unhook         |         |      +-------------------------+   |      +----------------------+
+#     +----------------+         |      | process input key       |   |      | `process_keyevent()` |
+#              |                 |      +-------------------------+   |      +----------------------+
+#              |                 |      | Predefined cursor event |->-+                |
+#         +--------+             |      |                         |                    |
+#         | finish |             |      | custom event            |---------->---------+
+#         +--------+             |      |                         |
+#                                +--<---| quit  event             |
+#                                       +-------------------------+
+#
 class _Interaction(ABC):
     def __init__(
         self,
@@ -300,6 +325,11 @@ class _Interaction(ABC):
     def process_raw_data(
         self, raw_data: list[str], width: int
     ) -> list[tuple[str, int]]:
+        """
+        Process the raw data, and indicate the number of additional
+        rows that need to be occupied when each piece of data is displayed.
+        """
+
         new_list = []
         for line in raw_data:
             text = Fx.uncolor(line)
@@ -319,51 +349,26 @@ class _Interaction(ABC):
         Support to process cursor line specially.
         """
 
-    def run(self, *args):
-        """Run method."""
+    def _loop(self):
         global _Interaction_Starting
 
-        # Make sure run at a git repo dir.
-        if not REPOSITORY_PATH:
-            color_print("Current path is not a git repository.", TermColor.Red)
-            return
-
-        self.width, self.height = width, height = get_terminal_size()
-
-        # Make sure have enough space.
-        if height < self._min_height or width < self._min_width:
-            raise InteractionError(
-                "The minimum size of terminal should be {0} x {1}.".format(
-                    self._min_width, self._min_height
-                )
-            )
-
-        if self._debug:  # debug show.
-            print(Fx.clear_)
-            print(width, height)
-            time.sleep(1.5)
+        width, height = self.width, self.height
 
         # Initialize.
         cursor_row: int = 1
-        display_range: list = [1, height - 1]  # allow display row range.
+        display_range: list = [1, height - 1]  # Allow display row range.
 
         stopping: bool = False  # Stop flag.
-        refresh: bool = False  # refresh data flag.
-
-        raw_data: list[Any] = self.get_raw_data()
-        self.raw_data = raw_data
-        if not raw_data:
-            print("The work tree is clean and there is nothing to operate.")
-            return
-        show_data = self.process_raw_data(raw_data, width)
-
+        refresh: bool = True  # Refresh flag. First into need refresh.
         extra = 0  # Extra occupied row.
 
-        # Into new term page.
         try:
             if not _Interaction_Starting:
                 _Interaction_Starting = True
-                print(Fx.alt_screen + Fx.hide_cursor)
+
+                # Into new term page.
+                print(Term.alt_screen + Term.hide_cursor)
+
                 #  try hook window resize event.
                 self._keyevent.signal_init()
 
@@ -371,24 +376,26 @@ class _Interaction(ABC):
             while not stopping:
                 if refresh:
                     refresh = False
+
                     raw_data: list[Any] = self.get_raw_data()
                     self.raw_data = raw_data
+                    if not raw_data:
+                        print("The work tree is clean and there is nothing to operate.")
+                        time.sleep(1)
+                        return
                     show_data = self.process_raw_data(raw_data, width)
 
-                print(Fx.clear_)
-
-                # check whether have status.
-                if not raw_data:
-                    print("The work tree is clean and there is nothing to operate.")
-                    time.sleep(1)
-                    return
+                print(Term.clear_screen)  # Clear full screen.
 
+                # Adjust display row range.
                 while cursor_row < display_range[0]:
                     display_range = [i - 1 for i in display_range]
                 while cursor_row + extra > display_range[1]:
                     display_range = [i + 1 for i in display_range]
 
-                extra = 0  # Return to zero and accumulate again.
+                # Every time refresh the output, need to recalculate the
+                # number of additional rows, so need to reset to zero.
+                extra = 0
 
                 # Print needed display part.
                 for index, item in enumerate(show_data, start=1):
@@ -397,7 +404,10 @@ class _Interaction(ABC):
                         self.print_line(line, index == cursor_row)
                         extra += each_extra
 
+                # Wait keyboard input.
                 input_key = self._keyevent.sync_get_input()
+
+                # Process key.
                 if input_key in ["q", "escape"]:
                     # exit.
                     stopping = True
@@ -436,7 +446,7 @@ class _Interaction(ABC):
                     display_range[1] += line_diff
                     show_data = self.process_raw_data(raw_data, width)
                 elif input_key in ["?", "h"]:
-                    print(Fx.clear_)
+                    print(Term.clear_screen)
                     print(
                         (
                             "k / ↑: select previous line.\n"
@@ -447,7 +457,7 @@ class _Interaction(ABC):
                             + self.keyevent_help()
                         ).format(self.help_wait)
                     )
-                    if self.help_wait == 0:
+                    if not self.help_wait or self.help_wait == 0:
                         self._keyevent.sync_get_input()
                     else:
                         time.sleep(self.help_wait)
@@ -461,4 +471,29 @@ class _Interaction(ABC):
             if _Interaction_Starting and not self._is_sub:
                 _Interaction_Starting = False
                 self._keyevent.signal_restore()
-                print(Fx.normal_screen + Fx.show_cursor, end="")
+                print(Term.normal_screen + Term.show_cursor, end="")
+
+    def run(self, *args):
+        """Run method."""
+
+        # Make sure run at a git repo dir.
+        if not REPOSITORY_PATH:
+            print(render_str("`Current path is not a git repository.`<error>"))
+            return
+
+        self.width, self.height = width, height = get_terminal_size()
+
+        # Make sure have enough space.
+        if height < self._min_height or width < self._min_width:
+            raise InteractionError(
+                "The minimum size of terminal should be {0} x {1}.".format(
+                    self._min_width, self._min_height
+                )
+            )
+
+        if self._debug:  # debug show.
+            print(Term.clear_screen)
+            print(width, height)
+            time.sleep(1.5)
+
+        return self._loop()  # Goto inner loop.
